==> eiffelstudio-18.01.10.1424.tar: F_code/C5/ar247.c <==
/*
 * Code for class ARGUMENTS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ar247.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ARGUMENTS}.argument */
EIF_REFERENCE F515_4711 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	Result = RTOSCF(4734,F515_4734,(Current));
	Result = F513_4679(RTCW(Result), arg1);
	Result = F995_8135(RTCW(Result));
	RTLE;
	return Result;
}

/* {ARGUMENTS}.argument_array */
static EIF_REFERENCE F515_4712_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	

	
	RTEV;
	RTOSP (4712);
#define Result RTOSR(4712)
	RTOC_NEW(Result);
	Result = F515_4733(Current);
	RTOSE (4712);
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F515_4712 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(4712,F515_4712_body,(Current));
}

/* {ARGUMENTS}.new_cursor */
EIF_REFERENCE F515_4715 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	Result = F646_4947(RTCV(RTOSCF(4712,F515_4712,(Current))));
	RTLE;
	return Result;
}

/* {ARGUMENTS}.argument_count */
EIF_INTEGER_32 F515_4729 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	Result = (EIF_INTEGER_32) eif_builtin_ARGUMENTS_32_argument_count (RTOSCF(4734,F515_4734,(Current)));
	RTLE;
	return Result;
}

/* {ARGUMENTS}.internal_argument_array */
EIF_REFERENCE F515_4733 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,645,0xFF01,1002,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 645, _OBJSIZ_1_1_0_2_0_0_0_0_);
	}
	tr2 = RTMS_EX_H("",0,0);
	ti4_1 = F515_4729(Current);
	F646_4938(RTCW(tr1), tr2, ((EIF_INTEGER_32) 0L), ti4_1);
	Result = (EIF_REFERENCE) tr1;
	F235_3500(RTCW(Result));
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > F515_4729(Current))) break;
		tr1 = F515_4711(Current, loc1);
		F646_4962(RTCW(Result), tr1, loc1);
		loc1++;
	}
	RTLE;
	return Result;
}

/* {ARGUMENTS}.internal_arguments */
static EIF_REFERENCE F515_4734_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (4734);
#define Result RTOSR(4734)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(512, 0x01).id, 512, _OBJSIZ_0_0_0_0_0_0_0_0_);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (4734);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F515_4734 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(4734,F515_4734_body,(Current));
}

void EIF_Minit247 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C5/ar247.c <==
/*
 * Code for class ARGUMENTS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ar247.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ARGUMENTS}.argument */
EIF_REFERENCE F515_4711 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	Result = RTOSCF(4734,F515_4734,(Current));
	Result = F513_4679(RTCW(Result), arg1);
	Result = F995_8137(RTCW(Result));
	RTLE;
	return Result;
}

/* {ARGUMENTS}.argument_array */
static EIF_REFERENCE F515_4712_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	

	
	RTEV;
	RTOSP (4712);
#define Result RTOSR(4712)
	RTOC_NEW(Result);
	Result = F515_4733(Current);
	RTOSE (4712);
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F515_4712 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(4712,F515_4712_body,(Current));
}

/* {ARGUMENTS}.new_cursor */
EIF_REFERENCE F515_4715 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	Result = F646_4947(RTCV(RTOSCF(4712,F515_4712,(Current))));
	RTLE;
	return Result;
}

/* {ARGUMENTS}.argument_count */
EIF_INTEGER_32 F515_4729 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	Result = (EIF_INTEGER_32) eif_builtin_ARGUMENTS_32_argument_count;
	RTLE;
	return Result;
}

/* {ARGUMENTS}.internal_argument_array */
EIF_REFERENCE F515_4733 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,Result);
	RTLIU(4);
	
	RTGC;
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,645,0xFF01,1002,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 645, _OBJSIZ_1_1_0_2_0_0_0_0_);
	}
	tr2 = RTMS_EX_H("",0,0);
	ti4_1 = F515_4729(Current);
	F646_4938(RTCW(tr1), tr2, ((EIF_INTEGER_32) 0L), ti4_1);
	Result = (EIF_REFERENCE) tr1;
	F235_3500(RTCW(Result));
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > F515_4729(Current))) break;
		tr1 = F515_4711(Current, loc1);
		F646_4962(RTCW(Result), tr1, loc1);
		loc1++;
	}
	RTLE;
	return Result;
}

/* {ARGUMENTS}.internal_arguments */
static EIF_REFERENCE F515_4734_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (4734);
#define Result RTOSR(4734)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(512, 0x01).id, 512, _OBJSIZ_0_0_0_0_0_0_0_0_);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (4734);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F515_4734 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(4734,F515_4734_body,(Current));
}

void EIF_Minit247 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
